# Generated by Django 4.2.23 on 2026-02-10 00:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("register", "0019_alter_attendee_permissions"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="attendee",
            name="confirm_covid_tests",
        ),
        migrations.RemoveField(
            model_name="attendee",
            name="vaccinated",
        ),
        migrations.RemoveField(
            model_name="attendee",
            name="vaccination_notes",
        ),
    ]
