# Generated by Django 4.2.23 on 2026-02-10 01:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("register", "0020_remove_covid19_form"),
    ]

    operations = [
        migrations.CreateModel(
            name="Allergen",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=16, unique=True)),
                ("description", models.CharField(max_length=32, unique=True)),
            ],
        ),
        migrations.AddField(
            model_name="food",
            name="allergens",
            field=models.ManyToManyField(to="register.allergen"),
        ),
    ]
